Contributors
============

This list includes people who have contributed to the project in the form of code,
comments, testing, bug reports, feature requests.

* `Louise Schoneveld <https://github.com/lavender22>`__
* `Morgan Williams <https://github.com/morganjwilliams>`__
